@@ -1,6 +1,6 @@
 ##
 ##  slice_pass3.pl -- Pass 3
-##  Copyright (c) 1997,1998 Ralf S. Engelschall. 
+##  Copyright (c) 1997,1998,1999 Ralf S. Engelschall. 
 ##
 
 package main;
@@ -24,7 +24,7 @@ sub pass3 {
     foreach $entry (@{$CFG->{OPT}->{O}}) {
 
         #   determine parameters
-        if ($entry =~ m|^([A-Z0-9~!+u*n\-\\^x()@]+):(.+)@(.+)$|) {
+        if ($entry =~ m|^([_A-Z0-9~!+u*n\-\\^x()@]+):(.+)@(.+)$|) {
             # full syntax
             ($slice, $outfile, $chmod) = ($1, $2, $3);
         }
@@ -42,16 +42,6 @@ sub pass3 {
         }
         &verbose("    file `$outfile': sliceterm='$slice', chmodopts='$chmod'\n");
 
-        #   open output file
-        if ($outfile eq '-') {
-            $out = new IO::Handle;
-            $out->fdopen(fileno(STDOUT), 'w');
-        }
-        else {
-            $out = new IO::File;
-            $out->open(">$outfile");
-        }
-
         #   now when there is plain data cut out the slices
         if (length($CFG->{INPUT}->{PLAIN}) > 0) {
             #   parse the sliceterm and create corresponding
@@ -73,23 +63,38 @@ sub pass3 {
             #   and move result to $set
             eval "$cmds; \$set = $var";
     
-            #   now scan the set and write out characters
-            #   which have a corresponding bit set.
-            $start = 0;
-            while (($start < $set->Size()) &&
-                   (($min, $max) = $set->Interval_Scan_inc($start))) {
-                $out->print(substr($CFG->{INPUT}->{PLAIN}, $min, ($max-$min+1)));
-                $start = $max + 2;
+            #   test if this slice is non-empty
+            if (! $set->is_empty) {
+
+                #   open output file
+                if ($outfile eq '-') {
+                    $out = new IO::Handle;
+                    $out->fdopen(fileno(STDOUT), 'w');
+                }
+                else {
+                    $out = new IO::File;
+                    $out->open(">$outfile");
+                }
+
+                #   now scan the set and write out characters
+                #   which have a corresponding bit set.
+                $start = 0;
+                while (($start < $set->Size()) &&
+                       (($min, $max) = $set->Interval_Scan_inc($start))) {
+                    $out->print(substr($CFG->{INPUT}->{PLAIN},
+                                       $min, ($max-$min+1)));
+                    $start = $max + 2;
+                }
+
+                #   close outputfile
+                $out->close;
+
+                #   additionally run chmod on the output file
+                if ($outfile ne '-' and $chmod ne '' and -f $outfile) {
+                    system("chmod $chmod $outfile");
+                }
             }
         }
-
-        #   close outputfile
-        $out->close;
-
-        #   additionally run chmod on the output file
-        if ($outfile ne '-' and $chmod ne '' and -f $outfile) {
-            system("chmod $chmod $outfile");
-        }
     }
 }
 
